Package: SubCellBarCode
Type: Package
Title: SubCellBarCode: Integrated workflow for robust mapping and
        visualizing whole human spatial proteome
Version: 1.27.0
Author: Taner Arslan
Maintainer: Taner Arslan <taner.arslan@ki.se>
Description: Mass-Spectrometry based spatial proteomics have enabled the proteome-wide mapping of protein subcellular localization (Orre et al. 2019, Molecular Cell). SubCellBarCode R package robustly classifies proteins into corresponding subcellular localization.
License: GPL-2
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.6)
Suggests: knitr, rmarkdown, BiocStyle
Imports: Rtsne, scatterplot3d, caret, e1071, ggplot2, gridExtra,
        networkD3, ggrepel, graphics, stats, org.Hs.eg.db,
        AnnotationDbi
biocViews: Proteomics, MassSpectrometry, Classification
RoxygenNote: 7.1.1
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/SubCellBarCode
git_branch: devel
git_last_commit: 945ded8
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-11-01 00:34:52 UTC; biocbuild
