#' @title Gefitinib treated HCC827 Cell Line Classification
#' @description Gefitinib treated HCC827 cell line classification
#' contains both neighborhood and compartment level. The data will be
#' used for the relocalization analysis.
#' @name hcc827GEFClass
#' @docType data
#' @usage hcc827GEFClass
#' @format A data frame where 10398 protein gene-centric ids and corresponding
#'compartment and neighborhood classification alon with
#'classification probabilities.
#'@keywords datasets
#'@examples {
#'head(hcc827GEFClass)
#'}
#' @references Orre et al. 2019 Cell 73, 1-17
NULL
