#' @title Gefitinib treated HCC827 Cell Line
#' @description HCC827 cell line was treated with Gefitinib which is
#' EGFR inhibition.
#' @name hcc827GEF
#' @docType data
#' @usage hcc827GEF
#' @format A data frame where 10398 protein gene-centric ids and 5
#' replicated subcellular fractions with duplicates.
#' @keywords datasets
#' @examples {
#'head(hcc827GEF)
#'}
#' @references Orre et al. 2019 Cell 73, 1-17
NULL
