#' @title Minimum PSM Count in HCC827 Gefitinib Cell Line.
#' @description Minimum PSM, Peptide Sequence Match, Count table
#' for HCC827 Gefitinib Cell Line.
#' @name hcc827GefPSMCount
#' @docType data
#' @usage hcc827GefPSMCount
#' @format A data frame where 10398 protein gene-centric ids minimum PSM count.
#' @keywords datasets
#' @examples {
#'head(hcc827GefPSMCount)
#'}
#' @references Orre et al. 2019 Cell 73, 1-17
NULL
