#' @title Marker Proteins Source
#' @description Data for the proteins whose localizations
#' were well characterized. It also contains color codes for each
#' compartment and median fractionation profiles for 5 fractions which are
#' Cyto., Nsol., NucI., Horg., Lorg., with replicates A and B. These
#' fractionation profiles will be used for the marker protein quality control.
#' @name markerProteins
#' @docType data
#' @usage markerProteins
#' @format A data frame of 3365 proteins as rows and 13 columns headers.
#' @keywords datasets
#' @references Orre et al. 2019 Cell 73, 1-17
NULL
