#' @title HCC827 Control Exon Cell Line
#' @description Exon-centric sub data of hcc827 fractionated data.
#' @name hcc827exon
#' @docType data
#' @usage hcc827exon
#' @format A data frame where 500 exon-centric ensemble identifiers,
#' corresponding gene symbols, 5 replicated subcellular fractions
#' and number of unique peptides matched to associated exon.
#' @keywords datasets
#' @examples {
#'head(hcc827exon)
#'}
#' @references Orre et al. 2019 Cell 73, 1-17
NULL
