#' @title HCC827 Control Cell Line
#' @description Subcellular fractionated cell line.
#' @name hcc827Ctrl
#' @docType data
#' @usage hcc827Ctrl
#' @format A data frame where 10480 protein gene-centric ids and
#' 5 replicated subcellular fractions.
#' @keywords datasets
#' @examples {
#'head(hcc827Ctrl)
#'}
#' @references Orre et al. 2019 Cell 73, 1-17
NULL
